@@ -17,6 +17,8 @@ class GenerateDataKeyTransferHandler(KmsTransferHandler):
         self.client = client
         self.action = action
         self.response_headers = [consts.MIGRATION_KEY_VERSION_ID_KEY]
+        self.accept_format = "JSON"
+        self.xml_root = "KMS"
 
     def get_client(self):
         return self.client
@@ -25,6 +27,7 @@ class GenerateDataKeyTransferHandler(KmsTransferHandler):
         return self.action
 
     def build_dkms_request(self, request, runtime_options):
+        self.accept_format = request.get_accept_format()
         generate_data_key_dkms_request = GenerateDataKeyRequest()
         generate_data_key_dkms_request.key_id = request.get_KeyId()
         key_spec = request.get_KeySpec()
@@ -47,12 +50,12 @@ class GenerateDataKeyTransferHandler(KmsTransferHandler):
 
     def transfer_response(self, response):
         response_headers = response.response_headers
-        version_id = response_headers.get(consts.MIGRATION_KEY_VERSION_ID_KEY)
-        if not response_headers or not version_id:
+        key_version_id = response_headers.get(consts.MIGRATION_KEY_VERSION_ID_KEY)
+        if not response_headers or not key_version_id:
             raise ClientException("",
                                   "Can not found response headers parameter[%s]" % consts.MIGRATION_KEY_VERSION_ID_KEY)
-        ciphertext_blob = version_id.encode("utf-8") + response.iv + response.ciphertext_blob
+        ciphertext_blob = key_version_id.encode("utf-8") + response.iv + response.ciphertext_blob
         body = {"KeyId": response.key_id, "CiphertextBlob": base64.b64encode(ciphertext_blob).decode("utf-8"),
                 "Plaintext": base64.b64encode(response.plaintext).decode("utf-8"),
-                "RequestId": response.request_id, "KeyVersionId": None}
-        return codes.OK, None, dict_to_body(body), None
+                "RequestId": response.request_id, "KeyVersionId": key_version_id}
+        return codes.OK, None, dict_to_body(body, self.accept_format, self.xml_root), None
